@@ -3,7 +3,7 @@ package WWW::BackpackTF::Item;
 use 5.014000;
 use strict;
 use warnings;
-our $VERSION = '0.001001';
+our $VERSION = '0.002';
 
 sub new{
 	my ($class, $name, $content) = @_;
@@ -35,6 +35,7 @@ WWW::BackpackTF::Item - Class representing item information
   use WWW::BackpackTF qw/VINTAGE GENUINE UNUSUAL/;
   use Data::Dumper qw/Dumper/;
 
+  my $bp = WWW::BackpackTF->new(key => '...');
   my @items = $bp->get_prices;
   my $item = $items[0];
   say 'Name: ', $item->name;
@@ -99,7 +100,7 @@ The difference bitween the former price and the current price. 0 if the current
 
 =head1 SEE ALSO
 
-L<http://backpack.tf/api/prices>
+L<http://backpack.tf/api/IGetPrices>
 
 =head1 AUTHOR
 
